@@ -1,15 +1,15 @@
-EOF = function(x, how = c("spatial", "temporal"), returnPredictions = TRUE, ...) { 
+EOF = function(x, how = c("spatial", "temporal"), returnPredictions = TRUE, 
+		...) { 
 	sp = x@sp
 	index = index(x@time)
 	x = as(x, "xts") # matrix
 	if (how[1] == "spatial") {
-		x = t(x)
-		pr = prcomp(x, ...)
+		pr = prcomp(~., data.frame(t(x)), ...)
 		if (! returnPredictions)
 			return(pr)
 		x = addAttrToGeom(sp, data.frame(predict(pr)), TRUE)
 	} else if (how[1] == "temporal") {
-		pr = prcomp(x, ...)
+		pr = prcomp(~., data.frame(x), ...)
 		if (! returnPredictions)
 			return(pr)
 		x = xts(data.frame(predict(pr)), index)
