@@ -8,26 +8,13 @@ if (!isGeneric("timeIsInterval<-"))
 
 setMethod("timeIsInterval", "ST",
 	function(x, ...) {
-		timeIsInterval(x@time)
+		any(index(x@time) < x@endTime)
 	}
 )
 
 setMethod("timeIsInterval", "ANY",
 	function(x, ...) {
-		a = attr(x, "timeIsInterval")
-		if (is.null(a) || is.na(a))
-			return(as.logical(NA))
-		stopifnot(is.logical(a))
-		a
-	}
-)
-
-setReplaceMethod("timeIsInterval", c("STT", "logical"),
-	function(x, value) {
-		if (isTRUE(value))
-			stop("timeIsInterval cannot be TRUE for STT objects")
-		attr(x@time, "timeIsInterval") = value
-		x
+		stop("timeIsInterval is not supported any longer; time intervals are obtained by specifying endTime")
 	}
 )
 
@@ -36,19 +23,17 @@ setReplaceMethod("timeIsInterval", c("ST", "logical"),
 		if (isTRUE(value)) {
 			if (min(diff(index(x@time))) <= 0)
 				warning("zero-width time intervals may yield invalid matching results")
+			x@endTime = delta(x@time)
 		}
-		attr(x@time, "timeIsInterval") = value
 		x
 	}
 )
 
-setReplaceMethod("timeIsInterval", c("ANY", "logical"), # including xts
+setReplaceMethod("timeIsInterval", c("ANY", "logical"),
 	function(x, value) {
-		if (isTRUE(value) && is(x, "xts")) {
-			if (min(diff(index(x))) <= 0)
-				warning("zero-width time intervals may yield invalid matching results")
-		}
-		attr(x, "timeIsInterval") = value
-		x
+		stop("timeIsInterval<- is not supported any longer; time intervals are obtained by specifying endTime")
 	}
 )
+
+if (!isClass("Intervals"))
+	setClass("Intervals")
